@@ -23,7 +23,7 @@ install <- function(pkgdir, dependencies, quiet, build, build_opts, build_manual
   install_deps(pkgdir, dependencies = dependencies, quiet = quiet,
     build = build, build_opts = build_opts, build_manual = build_manual,
     build_vignettes = build_vignettes, upgrade = upgrade, repos = repos,
-    type = type)
+    type = type, ...)
 
   if (isTRUE(build)) {
     dir <- tempfile()
